@@ -35,6 +35,7 @@ class Actions:
     action_clone_space_item = "clone_space_item"
     # clone a few types from one space to another space
     action_clone_space = "clone_space"
+    clone_space_actions = {action_clone_space_item, action_clone_space}
 
 
 def _parse_args():
@@ -59,11 +60,11 @@ def _parse_args():
                              'list like "accounts,actiontemplates,artifacts" is also accepted; '
                              'item types above Spaces: ' + ", ".join(item_types_only_ourter_space) +
                              "; \nitem types above and under Spaces: " + ", ".join(item_types_inside_space))
-    parser.add_argument("-it", "--item_type", help="one of item types above Spaces: " + ", ".join(
+    parser.add_argument("-tp", "--item_type", help="one of item types above Spaces: " + ", ".join(
         item_types_only_ourter_space) + "; \nitem types above and under Spaces: " + ", ".join(item_types_inside_space))
-    parser.add_argument("-in", "--item_name", help="item name: e.g. project_name")
+    parser.add_argument("-nm", "--item_name", help="item name: e.g. project_name")
     parser.add_argument("-id", "--item_id", help="item id: e.g. Lifecycles-1")
-    parser.add_argument("-bi", "--base_item_name", help="base item name, either local or on Octopus server")
+    parser.add_argument("-bn", "--base_item_name", help="base item name, either local or on Octopus server")
     parser.add_argument("-pn", "--parent_name", help="parent item name: e.g. project_name")
     parser.add_argument("-pt", "--parent_type", help="parent item type: e.g. projects")
     parser.add_argument("-ct", "--child_type", help=f"child item type: e.g. {item_type_deployment_processes}")
@@ -118,26 +119,27 @@ def run():
     print('config.octopus_name: ' + config.octopus_name)
 
     # verify space id/name
-    space_id = None
-    if args.space_id_name:
-        space_id = verify_space(space_id_or_name=args.space_id_name)
-        if space_id:
-            print(f"octopus space_id is: {space_id}")
-        else:
-            print(f"the space id/name {args.space_id_name} you specified does not exist")
-            return
-    else:
-        if input(f"Are you sure you want to run a command against null space [Y/n]? ") != 'Y':
-            return
-
     dst_space_id = None
     if args.dst_space_id_name:
         dst_space_id = verify_space(space_id_or_name=args.dst_space_id_name)
         if dst_space_id:
             print(f"destination space_id is: {dst_space_id}")
         else:
-            print(f"the destination space id/name {args.dst_space_id_name} you specified does not exist")
+            raise ValueError(f"the destination space id/name {args.dst_space_id_name} you specified does not exist")
+
+    space_id = None
+    if args.space_id_name:
+        space_id = verify_space(space_id_or_name=args.space_id_name)
+        if space_id:
+            print(f"octopus space_id is: {space_id}")
+        elif args.action not in Actions.clone_space_actions:
+            raise ValueError(f"the space id/name {args.space_id_name} you specified does not exist")
+        elif input(f"Are you sure you want to {args.action} from nonexistent space {args.space_id_name} [Y/n]?") == 'Y':
+            space_id = args.space_id_name
+        else:
             return
+    elif input(f"Are you sure you want to run a command against null space [Y/n]? ") != 'Y':
+        return
 
     if args.overwrite:
         config.overwrite = args.overwrite
